@@ -7,10 +7,12 @@ Objective Oriented Interface for AWS S3, similar to pathlib.
 from ._version import __version__
 
 __short_description__ = "Objective Oriented Interface for AWS S3, similar to pathlib."
-__license__ = "MIT"
+__license__ = "Apache License 2.0"
 __author__ = "Sanhe Hu"
 __author_email__ = "husanhe@gmail.com"
-__github_username__ = "MacHu-GWU"
+__maintainer__ = "Sanhe Hu"
+__maintainer_email__ = "sanhehu@amazon.com"
+__github_username__ = "aws-samples"
 
 try:
     from . import utils
